@@ -2,7 +2,8 @@ from .conv_coords            import *
 from .conv_angle             import *
 from .conv_geometric         import *
 from .conv_interpolators     import *
-from .conv_proj_carto        import *
+from .conv_proj_lambert      import *
+from .conv_proj_utm          import *
 from .conv_rotation_matrices import *
 from .conv_rinex             import *
 from .conv_time              import *  
