@@ -30,16 +30,40 @@ from geodezyx import conv
 from geodezyx import operational
 from geodezyx import utils
 
+#### Import the logger
+import logging
+log = logging.getLogger(__name__)
+
 ##########  END IMPORT  ##########
 
-def rinex_lister(path,add_new_names=True):
+def rinex_lister(path,add_long_names=True):
     """
     find all rinex in a folder and his subfolders
-    path can be a string or a tuple of string => manage multi files :)
+    path can be a string or a tuple of string => manage multi paths :)
 
-    is very similar with softs_runner.multi_finder_rinex and
-    gins_runner.get_rinex_list
+    is very similar with softs_runner.multi_finder_rinex,
+    gins_runner.get_rinex_list and operational.rinex_finder 
+    
+    Parameters
+    ----------
+    path : str
+        archive path.
+    add_long_names : bool, optional
+        consider new names. The default is True.
+
+    Returns
+    -------
+    rinexfilelist : list
+        list of rinex files.
+        
+    Notes
+    -----
+    
+    operational.rinex_finder must be used in priority !!! (July 2022)
     """
+    
+    log.warning("rinex_lister depreciated, use operational.rinex_finder instead!!")
+    
 
     if type(path) is str:
         path = [path]
@@ -54,102 +78,102 @@ def rinex_lister(path,add_new_names=True):
 
     wholefilelist = list(set(wholefilelist))
     
-    rinexfilelist           = [fil for fil in wholefilelist if re.search( conv.rinex_regex() , os.path.basename(fil))]
-    if add_new_names:
-        rinexfilelist_new_names = [fil for fil in wholefilelist if re.search( conv.rinex_regex_new_name() , os.path.basename(fil))]
+    rinexfilelist = [fil for fil in wholefilelist if re.search( conv.rinex_regex() , os.path.basename(fil))]
+    if add_long_names:
+        rinexfilelist_new_names = [fil for fil in wholefilelist if re.search( conv.rinex_regex_long_name() , os.path.basename(fil))]
         rinexfilelist = rinexfilelist + rinexfilelist_new_names
     
-    print('INFO : ' , len(rinexfilelist) , 'RINEXs found')
+    log.info('%s RINEXs found', len(rinexfilelist))
 
     return rinexfilelist
 
 
 
-def rinex_timeline(inputlist_or_paths,start = dt.datetime(1980,1,1) ,
-                   end = dt.datetime(2099,1,1),use_rinex_lister = True,
-                   dots_plot=False,jul_date_plot=False,return_figure=False):
+def rinex_timeline(inputlist_or_paths,
+                   start = dt.datetime(1980,1,1) ,
+                   end = dt.datetime(2099,1,1),
+                   use_rinex_lister = True,
+                   dots_plot=False,
+                   jul_date_plot=False,
+                   return_figure=False,
+                   xlim_start_end=False):
     """
-    if use_rinex_lister = True :
-    inputlist_or_paths is a path OR a list of path
-    where RINEX can be found (use the subfunction rinex_lister for that)
-    else if use_rinex_lister = False:
-    it's a list of RINEXs
+    Frontend function to plot the aviable RINEXs
+
+    Parameters
+    ----------
+    inputlist_or_paths : iterable
+        list of rinex file paths or list of archive directories.
+    start : datetime, optional
+        start of the plot time span. The default is dt.datetime(1980,1,1).
+    end : datetime, optional
+        end of the plot time span. The default is dt.datetime(2099,1,1).
+    use_rinex_lister : bool, optional
+        if True, inputlist_or_paths is a list of archive directories.
+        if False, inputlist_or_paths is a list of  rinex file paths.
+        The default is True.
+    dots_plot : bool, optional
+        print dots instead of line.
+        This mode should be avoided because it is slower.
+        The default is False.
+    jul_date_plot : bool, optional
+        Plot the date in julian dates. The default is False.
+    return_figure : bool, optional
+        returns figure. The default is False.
+    xlim_start_end : bool, optional
+        Force start and end values to be the x axis limit
+        The default is False.
+
+    Returns
+    -------
+    datadico : dict
+        datadico.
+    fig : matplotlib figure
+        figure
+
     """
-
-#    if use_rinex_lister:
-#        filelist = rinex_lister(inputlist_or_paths)
-#    else:
-#        filelist = inputlist_or_paths
-#
-#    rinexfilelist = [fil for fil in filelist if re.match( '.*' + conv.rinex_regex() + '$', fil)]
-#
-#    if not use_rinex_lister:
-#        rinexfilelist = [os.path.basename(e) for e in rinexfilelist]
-#
-#    print('INFO : ', len(rinexfilelist), 'RINEXs will be ploted on the timeline')
-#
-#    statname_lis = sorted(list(set([rin[0:4] for rin in rinexfilelist])))
-#
-#    print('INFO : ', len(statname_lis), 'stations will be ploted on the timeline')
-#
-#    datadico = dict()
-#
-#    for stat in statname_lis:
-#        datadico[stat] = []
-#
-#    for rnx in rinexfilelist:
-#        try:
-#            datadico[rnx[0:4]].append((rnx,rinexname2dt(rnx)))
-#        except:
-#            print('error with : ', rnx)
-#
-
+    
     datadico = rinex_timeline_datadico(inputlist_or_paths,
                                        use_rinex_lister = use_rinex_lister)
 
     fig  = timeline_plotter(datadico,start = start ,
                      end=end ,dots_plot=dots_plot,
-                     jul_date_plot=jul_date_plot)
+                     jul_date_plot=jul_date_plot,
+                     xlim_start_end=xlim_start_end)
 
-#    ax.xaxis.grid(True)
-#    plotstat_lis = []
-#    for i,stat in enumerate(reversed(sorted(datadico.keys()))):
-#        print(stat)
-#        T = [ e[-1] for e in datadico[stat] ]
-#        T = [ t for t in T if start <= t <= end ]
-#        T = sorted(T)
-#
-#        plotstat_lis.append(stat)
-#        if dots_plot:
-#            #old old with dots
-#            ax.plot(T,i*np.ones(len(T)), '.')
-#        else:
-#            TGrp = utils.consecutive_groupIt(dt2MJD(T),True)
-#            for tgrp in TGrp:
-#                if not jul_date_plot:
-#                    tgrp = MJD2dt(tgrp)
-#                if tgrp[0] == tgrp[1]:
-#                    ax.plot(tgrp[0],i, '.')
-#                else:
-#                    ax.plot(tgrp,[i]*2, '-')
-#
-##    ax.set_yticks(np.arange(0,len(plotstat_lis)-1),plotstat_lis)
-#    plt.yticks(np.arange(0,len(plotstat_lis)),plotstat_lis)
-#    fig.autofmt_xdate()
-#    fig.set_size_inches(11.69,i * 0.28) #16.53
-#    ax.set_ylim([-1 , len(plotstat_lis) + 1])
-##    return fig
     if not return_figure:
         return datadico
     else:
         return datadico , fig
 
-def rinex_timeline_datadico(inputlist_or_paths,use_rinex_lister = True,
+
+
+def rinex_timeline_datadico(inputlist_or_paths,
+                            use_rinex_lister = True,
                             optional_info=''):
     """
-    convention for RINEX datadico :
+    Generate a RINEX datadico
+
+    Parameters
+    ----------
+    inputlist_or_paths : iterable
+        list of rinex file paths or list of archive directories.
+    use_rinex_lister : bool, optional
+        if True, inputlist_or_paths is a list of archive directories.
+        if False, inputlist_or_paths is a list of  rinex file paths.
+        The default is True.
+    optional_info : str, optional
+        A addtional information for the rinexs found.
+        Usually it is the archive name
+        The default is ''.
+
+    Returns
+    -------
+    datadico : dict
         datadico[stat] = [(rinexname1,optional1,date1) ... (rinexnameN,optionalN,dateN)]
     """
+    
+    
     if use_rinex_lister:
         filelist = rinex_lister(inputlist_or_paths)
     else:
@@ -157,18 +181,18 @@ def rinex_timeline_datadico(inputlist_or_paths,use_rinex_lister = True,
 
     #rinexfilelist = [fil for fil in filelist if re.search( '.*' + conv.rinex_regex() + '$', fil)]
     rinexfilelist_old = [fil for fil in filelist if re.search( conv.rinex_regex() , fil)]
-    rinexfilelist_new = [fil for fil in filelist if re.search( conv.rinex_regex_new_name() , fil)]
+    rinexfilelist_new = [fil for fil in filelist if re.search( conv.rinex_regex_long_name() , fil)]
 
     rinexfilelist = rinexfilelist_old + rinexfilelist_new
 
     if not use_rinex_lister:
         rinexfilelist = [os.path.basename(e) for e in rinexfilelist]
 
-    print('INFO : ', len(rinexfilelist), 'RINEXs will be ploted on the timeline')
+    log.info('%s RINEXs will be ploted on the timeline',len(rinexfilelist))
 
     statname_lis = sorted(list(set([rin[0:4] for rin in rinexfilelist])))
 
-    print('INFO : ', len(statname_lis), 'stations will be ploted on the timeline')
+    log.info('%s stations will be ploted on the timeline',len(statname_lis))
 
     datadico = dict()
 
@@ -179,63 +203,29 @@ def rinex_timeline_datadico(inputlist_or_paths,use_rinex_lister = True,
         try:
             datadico[rnx[0:4]].append((rnx,optional_info,conv.rinexname2dt(rnx)))
         except:
-            print('error with : ', rnx)
+            log.error('error with : %s', rnx)
 
     return datadico
 
-def rinex_timeline_datadico_merge_not_very_smart(datadico_list,priority_list):
+def rinex_timeline_datadico_merge(datadico_list,priority_list=None):  
     """
     Merge different RINEXs datadico, produced by rinex_timeline_datadico
     coming from different archives
-    Args :
-        rinex_timeline_datadico : list of RINEX datadico
-        priority_list : priority list of 'optional_info' (archive ID)
-                        it will erase optional_info of lower priority
-    Returns :
-        datadico_out : a merged datadico
-    """
 
-    datadico_out  = dict()
+    Parameters
+    ----------
+    datadico_list : list of dict
+        list of RINEX datadico.
+    priority_list : list, optional
+        priority list of 'optional_info' (archive ID)
+        it will erase optional_info of lower priority
+        NB : it is not very useful, just sort datadico_list in the right order ....
+        The default is None.
 
-    datadico_merged = utils.dicts_of_list_merge(*datadico_list)
-
-    for k , dataval in datadico_merged.items():
-
-        rnxname_list = [e[0]  for e in dataval]
-        archive_list = [e[1]  for e in dataval]
-        date_list    = [e[-1] for e in dataval]
-
-        out_date_list , out_all_list = [] , []
-        for r,a,d in zip(rnxname_list,archive_list,date_list):
-            if d not in out_date_list:
-                out_date_list.append(d)
-                out_all_list.append((r,a,d))
-            else:
-                ind_existing   = out_date_list.index(d)
-                archd_existing = out_all_list[ind_existing][1]
-                if priority_list.index(a) < priority_list.index(archd_existing):
-                    out_date_list.remove(d)
-                    out_all_list.remove(out_all_list[ind_existing])
-                    out_date_list.append(d)
-                    out_all_list.append((r,a,d))
-
-        datadico_out[k] = out_all_list
-
-    return datadico_out
-
-
-def rinex_timeline_datadico_merge(datadico_list,priority_list=None):
-    """
-    Merge different RINEXs datadico, produced by rinex_timeline_datadico
-    coming from different archives
-    Args :
-        rinex_timeline_datadico : list of RINEX datadico
-        priority_list : priority list of 'optional_info' (archive ID)
-                        it will erase optional_info of lower priority
-                        NB : it is not very useful, just sort
-                             datadico_list in the right order ...
-    Returns :
-        datadico_out : a merged datadico
+    Returns
+    -------
+    datadico_out : dict
+        a merged datadico
     """
 
     datadico_out  = dict()
@@ -268,14 +258,56 @@ def rinex_timeline_datadico_merge(datadico_list,priority_list=None):
 
     return datadico_out
 
-def timeline_plotter(datadico,start = dt.datetime(1980,1,1) ,
-                     end = dt.datetime(2099,1,1),dots_plot=False,
-                     jul_date_plot=False,datadico_anex_list = [],
+def timeline_plotter(datadico,
+                     start = dt.datetime(1980,1,1) ,
+                     end = dt.datetime(2099,1,1),
+                     dots_plot=False,
+                     jul_date_plot=False,
+                     datadico_anex_list = [],
                      use_only_stats_of_main_datadico=False,
-                     colordico_for_main_datadico=None):
+                     colordico_for_main_datadico=None,
+                     xlim_start_end=False):
     """
-    A simpler version has been commited to geodezyx toolbox for archive
+    
+
+    Parameters
+    ----------
+    datadico : dict
+        a RINEX datadico (see rinex_timeline_datadico for details).
+    start : datetime, optional
+        start of the plot time span. The default is dt.datetime(1980,1,1).
+    end : datetime, optional
+        end of the plot time span. The default is dt.datetime(2099,1,1).
+    dots_plot : TYPE, optional
+        print dots instead of line.
+        This mode should be avoided because it is slower.
+        The default is False.
+    jul_date_plot : bool, optional
+        Plot the date in julian dates. The default is False.
+    datadico_anex_list : list, optional
+        A list of secondary datadicos. The default is [].
+    use_only_stats_of_main_datadico : bool, optional
+        Use only stats of main datadico. 
+        Advanced usage.
+        The default is False.
+    colordico_for_main_datadico : dict, optional
+        Color for the main datadico.
+        Advanced usage.
+        The default is None.
+    xlim_start_end : bool, optional
+        Force start and end values to be the x axis limit
+        The default is False.
+
+    Returns
+    -------
+    fig : matplotlib figure
+        figure
+
+    Notes
+    -----
+    A simpler version has been commited to geodezyx toolbox GitHub for archive
     on 20180118 15:59A
+    
     """
 
     fig , ax = plt.subplots()
@@ -340,13 +372,12 @@ def timeline_plotter(datadico,start = dt.datetime(1980,1,1) ,
                     TSubgrp = utils.sublistsIt(Tgrp , [len(e) for e in OSubgrp])
 
                     Tgrp_plt      = [ (e[0] , e[-1] + 1)    for e in TSubgrp ] # +1 because the end boundary day is not included
-                    Ogrp_plt      = [ list(set(e))[0] for e in OSubgrp     ]
+                    Ogrp_plt      = [ list(set(e))[0] for e in OSubgrp ]
                     Color_grp_plt = [ colordico_for_main_datadico[e] if e in colordico_for_main_datadico else color2 for e in Ogrp_plt ]
             ###*** End of managing colors
 
             tgrp = (tgrp[0] , tgrp[1] + 1) # +1 because the end boundary day is not included
                                            # must stay there, in case of not colordico_for_main_datadico
-
             if not jul_date_plot:
                 tgrp = conv.MJD2dt(tgrp)
                 if extra_archive:
@@ -384,17 +415,165 @@ def timeline_plotter(datadico,start = dt.datetime(1980,1,1) ,
             plt.legend(handles=legend_list,loc='upper left',ncol=3,
                        columnspacing=1)
 
-
 #    ax.set_yticks(np.arange(0,len(plotstat_lis)-1),plotstat_lis)
     plt.yticks(np.arange(0,len(stats_concat_list)),stats_concat_list)
     fig.autofmt_xdate()
     koef = np.sqrt(2) * 1
     fig.set_size_inches(koef*11.69,koef*len(stats_concat_list) * 0.28) #16.53
     ax.set_ylim([-1 , len(stats_concat_list) + 1])
+    ax.set_xlim([start,end])
 
     return fig
 
 
+def rinex_check_epochs_availability(rinex_path_list):
+    """
+    Gives simple statistics about RINEX avaiability for all the listed stations
+
+    Parameters
+    ----------
+    rinex_path_list : list
+        A list of rinex paths
+
+    Returns
+    -------
+    T : str
+        a table with statistics.
+
+    """
+
+    results_stk = []
+
+    for rinex_path in rinex_path_list:
+
+        rinex_name = os.path.basename(rinex_path)
+
+        QC = operational.teqc_qc(rinex_path)
+
+        if not QC:
+            continue
+
+        epoc_all  = int(utils.egrep_big_string("Poss. # of obs epochs" ,QC,
+                                               only_first_occur=True).split()[-1])
+        epoc_disp = int(utils.egrep_big_string("Epochs w/ observations",QC,
+                                               only_first_occur=True).split()[-1])
+
+        dt_rnx = conv.rinexname2dt(rinex_name)
+
+        date_str = conv.dt2str(dt_rnx,"%F")
+
+        percentage = (float(epoc_disp) / float(epoc_all)) * 100.
+
+        results = [rinex_name,date_str,epoc_disp,epoc_all,percentage]
+
+        results_stk.append(results)
+
+    header = ['RINEX','date','Avbl.', 'Poss.', '%']
+    T = tabulate.tabulate(results_stk,headers=header)
+
+    return T
+
+
+
+def listing_gins_timeline(path,stat_strt,stat_end,date_strt,date_end,suffix_regex=''):
+    """ find all gins listings in a folder and his subfolders
+        and plot timeline of the avaiable listings
+
+        stat_strt,stat_end,date_strt,stat_end : where to find
+        in the name the statname and the date"""
+
+    fig , ax = plt.subplots()
+
+    aaa = list(os.walk(path))
+    wholefilelist = []
+    for tup in aaa:
+        wholefilelist = wholefilelist + tup[-1]
+
+    wholefilelist = list(set(wholefilelist))
+    lifilelist = [fil for fil in wholefilelist if re.search(suffix_regex +'.*\gins', fil)]
+
+    statname_lis = sorted(list(set([li[stat_strt:stat_end] for li in lifilelist])))
+
+    list(set(statname_lis))
+
+    datadico = dict()
+
+    for stat in statname_lis:
+        datadico[stat] = []
+
+    for li in lifilelist:
+        try:
+            tup = (li , conv.jjulCNES2dt(li[date_strt:date_end] ))
+            datadico[li[stat_strt:stat_end]].append(tup)
+        except:
+            log.error('error with : %s', li)
+    plotstat_lis = []
+    for i,stat in enumerate(sorted(datadico.keys())):
+        log.info("%s %s",i , stat)
+        T = [e[-1] for e in datadico[stat]]
+        plotstat_lis.append(stat)
+        ax.plot(T,i*np.ones(len(T)), '.')
+
+    i_list = np.arange(0,len(plotstat_lis))
+
+    plt.yticks(i_list,plotstat_lis)
+
+    return fig
+
+
+
+
+#  ______                _   _                _____                                         _ 
+# |  ____|              | | (_)              / ____|                                       | |
+# | |__ _   _ _ __   ___| |_ _  ___  _ __   | |  __ _ __ __ ___   _____ _   _  __ _ _ __ __| |
+# |  __| | | | '_ \ / __| __| |/ _ \| '_ \  | | |_ | '__/ _` \ \ / / _ \ | | |/ _` | '__/ _` |
+# | |  | |_| | | | | (__| |_| | (_) | | | | | |__| | | | (_| |\ V /  __/ |_| | (_| | | | (_| |
+# |_|   \__,_|_| |_|\___|\__|_|\___/|_| |_|  \_____|_|  \__,_| \_/ \___|\__, |\__,_|_|  \__,_|
+#                                                                        __/ |                
+#                                                                       |___/ 
+
+
+
+def rinex_timeline_datadico_merge_not_very_smart(datadico_list,priority_list):
+    """
+    Merge different RINEXs datadico, produced by rinex_timeline_datadico
+    coming from different archives
+    Args :
+        rinex_timeline_datadico : list of RINEX datadico
+        priority_list : priority list of 'optional_info' (archive ID)
+                        it will erase optional_info of lower priority
+    Returns :
+        datadico_out : a merged datadico
+    """
+
+    datadico_out  = dict()
+
+    datadico_merged = utils.dicts_of_list_merge(*datadico_list)
+
+    for k , dataval in datadico_merged.items():
+
+        rnxname_list = [e[0]  for e in dataval]
+        archive_list = [e[1]  for e in dataval]
+        date_list    = [e[-1] for e in dataval]
+
+        out_date_list , out_all_list = [] , []
+        for r,a,d in zip(rnxname_list,archive_list,date_list):
+            if d not in out_date_list:
+                out_date_list.append(d)
+                out_all_list.append((r,a,d))
+            else:
+                ind_existing   = out_date_list.index(d)
+                archd_existing = out_all_list[ind_existing][1]
+                if priority_list.index(a) < priority_list.index(archd_existing):
+                    out_date_list.remove(d)
+                    out_all_list.remove(out_all_list[ind_existing])
+                    out_date_list.append(d)
+                    out_all_list.append((r,a,d))
+
+        datadico_out[k] = out_all_list
+
+    return datadico_out
+
 # def timeline_plotter_old_bkp(datadico,start = dt.datetime(1980,1,1) ,
 #                      end = dt.datetime(2099,1,1),dots_plot=False,
 #                      jul_date_plot=False,datadico_anex_list = [],
@@ -540,86 +719,5 @@ def timeline_plotter(datadico,start = dt.datetime(1980,1,1) ,
 #                                    Color_extra.append(color2)
 
 
-def listing_gins_timeline(path,stat_strt,stat_end,date_strt,date_end,suffix_regex=''):
-    """ find all gins listings in a folder and his subfolders
-        and plot timeline of the avaiable listings
-
-        stat_strt,stat_end,date_strt,stat_end : where to find
-        in the name the statname and the date"""
-
-    fig , ax = plt.subplots()
-
-    aaa = list(os.walk(path))
-    wholefilelist = []
-    for tup in aaa:
-        wholefilelist = wholefilelist + tup[-1]
-
-    wholefilelist = list(set(wholefilelist))
-    lifilelist = [fil for fil in wholefilelist if re.search(suffix_regex +'.*\gins', fil)]
-
-    statname_lis = sorted(list(set([li[stat_strt:stat_end] for li in lifilelist])))
-
-    list(set(statname_lis))
-
-    datadico = dict()
-
-    for stat in statname_lis:
-        datadico[stat] = []
-
-    for li in lifilelist:
-        try:
-            tup = (li , conv.jjulCNES2dt(li[date_strt:date_end] ))
-            datadico[li[stat_strt:stat_end]].append(tup)
-        except:
-            print('error with : ', li)
-    plotstat_lis = []
-    for i,stat in enumerate(sorted(datadico.keys())):
-        print(i , stat)
-        T = [e[-1] for e in datadico[stat]]
-        plotstat_lis.append(stat)
-        ax.plot(T,i*np.ones(len(T)), '.')
-
-    i_list = np.arange(0,len(plotstat_lis))
-
-    print(i_list)
-    plt.yticks(i_list,plotstat_lis)
-
-    return fig
 
 
-def rinex_check_epochs_availability(rinex_path_list):
-    """
-    Args :
-        A list of rinex paths
-    Returns :
-        T : a table with results
-    """
-
-    results_stk = []
-
-    for rinex_path in rinex_path_list:
-
-        rinex_name = os.path.basename(rinex_path)
-
-        QC = operational.teqc_qc(rinex_path)
-
-        if not QC:
-            continue
-
-        epoc_all  = int(utils.egrep_big_string("Poss. # of obs epochs" ,QC,only_first_occur=True).split()[-1])
-        epoc_disp = int(utils.egrep_big_string("Epochs w/ observations",QC,only_first_occur=True).split()[-1])
-
-        dt_rnx = conv.rinexname2dt(rinex_name)
-
-        date_str = conv.dt2str(dt_rnx,"%F")
-
-        percentage = (float(epoc_disp) / float(epoc_all)) * 100.
-
-        results = [rinex_name,date_str,epoc_disp,epoc_all,percentage]
-
-        results_stk.append(results)
-
-    header = ['RINEX','date','Avbl.', 'Poss.', '%']
-    T = tabulate.tabulate(results_stk,headers=header)
-
-    return T
