@@ -30,6 +30,10 @@ from geodezyx import conv
 from geodezyx import stats
 from geodezyx import utils
 
+#### Import the logger
+import logging
+log = logging.getLogger(__name__)
+
 ##########  END IMPORT  ##########
 
 
@@ -101,8 +105,8 @@ def itrf_psd_fundamuntal_formula(t,A_l,t_l,tau_l,A_e,t_e,tau_e):
     dL : TYPE
         the total sum of PSD corrections.
 
-    Source
-    ------
+    References
+    ----------
         http://itrf.ensg.ign.fr/ITRF_solutions/2014/doc/ITRF2014-PSD-model-eqs-IGN.pdf
     """
     
@@ -262,14 +266,14 @@ ITRF14,ITRF88,2010.0,25.4,-0.5,-154.8,11.29,0.10,0.00,0.26,0.1,-0.5,-3.3,0.12,0.
     epoch_ref_Xe = DF3["TRF_E_epoch"]
     
     if verbose:
-        print("INFO:itrf_helmert_get_parameters:",TRF_Input_name,"=>",TRF_Ext_name)
-        print("   T:",T,Tdot)
-        print("   D:",D,Ddot)
-        print("   R:",R,Rdot)
-        print("t Xe:",epoch_ref_Xe)
-        print(" Inv:",inver_bool)
-        print("DataFrame:")
-        print(DF2)
+        log.info("%s => %s",TRF_Input_name,TRF_Ext_name)
+        log.info("   T: %s",T,Tdot)
+        log.info("   D: %s",D,Ddot)
+        log.info("   R: %s",R,Rdot)
+        log.info("t Xe: %s",epoch_ref_Xe)
+        log.info(" Inv: %s",inver_bool)
+        log.info("DataFrame:")
+        log.info(DF2)
     
     return T,Tdot,D,Ddot,R,Rdot,epoch_ref_Xe
 
@@ -313,16 +317,19 @@ def itrf_helmert_trans(Xi,
     Xe : 3-Array or Nx3-Array
         Points in the destination Reference Frame.
         
-    Warning
-    -------
+
+        
+    Notes
+    -----
+    
+    ** Warning **
     This function does not the velocity shift from one epoch to another \n
     The output coordinates will be provided at the same epoch as the input ones \n
     Use ``itrf_speed_calc`` function to perform this potential step 
     before (with the initial velocities) or after (with the transformed velocities)
     calling the present function.
-        
-    Notes
-    -----
+    
+    
     Based on the theory and values of *EUREF Technical Note 1: 
     Relationship and Transformation between the International 
     and the European Terrestrial Reference Systems, Z. Altamimi, 2018*
@@ -332,24 +339,23 @@ def itrf_helmert_trans(Xi,
     http://www.epncb.oma.be/_productsservices/coord_trans/index.php
     
     
-    Notes for the French geodetic system
-    ------------------------------------
-    
+    ** Notes for the French geodetic system **    
     By definition, since the 2021/01/04
     RGF93(v2b) = ETRF2000@2019.0
     
-    Source:
-        https://geodesie.ign.fr/index.php?page=rgf93 \n
-        https://geodesie.ign.fr/contenu/fichiers/RGF93v2b-RAF18b.pdf \n
-        https://geodesie.ign.fr/contenu/fichiers/rgf93v2b_information_cnig.pdf 
+    References
+    ----------
+    https://geodesie.ign.fr/index.php?page=rgf93 \n
+    https://geodesie.ign.fr/contenu/fichiers/RGF93v2b-RAF18b.pdf \n
+    https://geodesie.ign.fr/contenu/fichiers/rgf93v2b_information_cnig.pdf 
     
     """
     ## prelimiary warning 
     if utils.is_iterable(epoch_Xi):
-        print("WARN:itrf_helmert_trans: epoch_Xi is an iterable !!!")
-        print("     The function works correctly with a single epoch only !!!")
-        print("     If several initial Reference Frame epoch")
-        print("     use a loop outside the function")
+        log.warning("epoch_Xi is an iterable !!!")
+        log.info("The function works correctly with a single epoch only !!!")
+        log.info("if several initial Reference Frame epoch")
+        log.info("use a loop outside the function")
         
     
     if not type(Xi) is np.array:
@@ -484,8 +490,8 @@ def helmert_trans_estim(X1list , X2list, Weights=[]):
     l :
         Differences X2 - X1 (before transformation !!!)
         
-    Source
-    ------
+    References
+    ----------
     https://elib.uni-stuttgart.de/bitstream/11682/9661/1/BscThesis_GaoYueqing.pdf
     """
 
@@ -496,7 +502,7 @@ def helmert_trans_estim(X1list , X2list, Weights=[]):
     for X1 , X2 in zip(X1list , X2list):
         
         if np.sum(np.isnan(X1)) or np.sum(np.isnan(X2)):
-            print("WARN: helmert_trans_estim: one point component is nan, skipping")
+            log.warning("one point component is nan, skipping")
             Bool_stk.append(False)
             continue
         
@@ -635,9 +641,9 @@ def helmert_trans_estim_minimisation(X1in,X2in,HParam_apri=np.zeros(7),
                                            'ftol':tol})
     
     if RES.status != 0:
-        print("WARN: helmert_trans_estim_minimisation: something went wrong (status != 0)")
-        print("      here is the scipy.optimize.minimize message")
-        print("    > " + RES.message)
+        log.warning("something went wrong (status != 0)")
+        log.warning("here is the scipy.optimize.minimize message")
+        log.warning(" > " + RES.message)
     
     if not full_output:
         return RES.x
@@ -652,10 +658,28 @@ def helmert_trans_estim_minimisation_scalar(X1,X2,HParam_opti_apriori,
     
     NOT STABLE AVOID THE USE
     (it does the optimization of the 1st parameter, 
-     and then the optimization of the 2nd one etc, etc...)
+    and then the optimization of the 2nd one etc, etc...)
+
+    Parameters
+    ----------
+    X1 & X2 : list of N (x,y,z) points, or an (N,3)-shaped numpy array
+        Input point sets
+    HParam_opti_apriori : list of 7 values
+        The Apriori for the Helmert parameter 
+    L1norm : bool
+        Use the L1-norm as a criteria, use the quadratic sum instead if False
+    itera : int, optional
+        number of iterations. The default is 2.
+
+    Returns
+    -------
+    TYPE
+        DESCRIPTION.
+
     """
+
     
-    print("WARN : helmert_trans_estim_minimisation_scalar unstable, avoid !!!!!")
+    log.warning("unstable approach, avoid !!!!!")
     
     def minimiz_helmert_fct_scalar(hparam_mono_in,hparam_mono_id,
                             HParam_mini_in,X1in,X2in):
@@ -683,7 +707,7 @@ def helmert_trans_estim_minimisation_scalar(X1,X2,HParam_opti_apriori,
         if not j:
             HParam_opti_prev = HParam_opti_wrk.copy()
         else:
-            print("Helmert Param minimisation iter",j+1,HParam_opti_wrk - HParam_opti_prev)
+            log.info("Helmert Param minimisation iter %s %s",j+1,HParam_opti_wrk - HParam_opti_prev)
             HParam_opti_prev = HParam_opti_wrk.copy()
                         
     return HParam_opti_wrk
@@ -804,7 +828,7 @@ def rotate_points(alphal,betal,gammal,pointlin,Rtype='R1',
     for pt in pointlin:
 
         if not utils.is_iterable(pt) or len(pt) != 3:
-            print("ERR : rotate_points : pts != 3 coords")
+            log.error("pts != 3 coords")
             return 0
 
         pointltmp = []
@@ -1075,15 +1099,15 @@ def random_walk_in_a_circle(x0 , y0 , xc , yc ,
         
     Exemple
     -------
-        for un in ('u','n'):
-        for pol in range(2):
-            X,Y , Xcircle , Ycircle = random_walk_in_a_circle(10,10,0,0,50,10000,polar = pol,uniform_or_normal=un)
+    for un in ('u','n'):
+    for pol in range(2):
+        X,Y , Xcircle , Ycircle = random_walk_in_a_circle(10,10,0,0,50,10000,polar = pol,uniform_or_normal=un)
 
-            plt.figure()
-            plt.plot(Xcircle,Ycircle)
-            plt.plot(X,Y)
-            plt.axis('equal')
-            plt.suptitle(un + str(pol))
+        plt.figure()
+        plt.plot(Xcircle,Ycircle)
+        plt.plot(X,Y)
+        plt.axis('equal')
+        plt.suptitle(un + str(pol))
 
     """
 
@@ -1103,7 +1127,7 @@ def random_walk_in_a_circle(x0 , y0 , xc , yc ,
         while D > R:
             iwhil += 1
             if iwhil > 500:
-                print('WARN : infinite loop in random_walk_in_a_circle ...' , iwhil)
+                log.warning('infinite loop in random_walk_in_a_circle ... %s')
             if polar:
                 if uniform_or_normal == 'u':
                     dalpha = RAND.uniform(-param,param) * 2 * np.pi
@@ -1120,7 +1144,7 @@ def random_walk_in_a_circle(x0 , y0 , xc , yc ,
                 else:
                     dx = np.random.normal(0,param)
                     dy = np.random.normal(0,param)
-                print(dx , dy)
+
             xtemp = X[-1] + dx
             ytemp = Y[-1] + dy
             D = np.sqrt((xtemp - xc)**2 + (ytemp - yc)**2)
@@ -1249,8 +1273,8 @@ def project_point_on_plan(N,M,A):
     ----
     It can be an ambiguity on the sign
     
-    Source
-    ------
+    References
+    ----------
     https://fr.wikipedia.org/wiki/Distance_d%27un_point_%C3%A0_un_plan
     https://www.mathematex.fr/viewtopic.php?t=923    
     """
@@ -1279,7 +1303,26 @@ def helmert_trans_legacy(Xa,params='itrf2008_2_etrf2000',
                          invert=True,workepoc=2009.):
     """
     This function is highly unstable and should be used only for legacy reason
+
+
+    Parameters
+    ----------
+    Xa : TYPE
+        DESCRIPTION.
+    params : TYPE, optional
+        DESCRIPTION. The default is 'itrf2008_2_etrf2000'.
+    invert : TYPE, optional
+        DESCRIPTION. The default is True.
+    workepoc : TYPE, optional
+        DESCRIPTION. The default is 2009..
     
+    Returns
+    -------
+    Xb : TYPE
+        DESCRIPTION.
+        
+    Notes
+    -----
     NB 1 : http://etrs89.ensg.ign.fr/memo-V8.pdf
     NB 2 :
     Transformation inverse : * -1 pour les paramètres
@@ -1288,17 +1331,23 @@ def helmert_trans_legacy(Xa,params='itrf2008_2_etrf2000',
     optimisé pour RGF93 => ITRF2008 (d'ou le invert = True & workepoc = 2009.)
 
     NB3 : Attention losque l'on compare avec
-          le convertisseur EUREF avec une vitesse
-          parce que elle aussi est modifiée dans la conversion ETRS => ITRS.
-          Conclusion : le faire en 2 étapes ETRS = > ITRS dans la même epoc
-                                            ITRS epoc 1 => ITRS epoc 2
+    le convertisseur EUREF avec une vitesse
+    parce que elle aussi est modifiée dans la conversion ETRS => ITRS.
+    Conclusion : le faire en 2 étapes: 
+    ETRS => ITRS dans la même epoc
+    ITRS epoc 1 => ITRS epoc 2
+                                            
+    NE MARCHE PAS PARCE BESOIN DU RATE(TAUX) DES PARAMS D'HELMERT !!!!!!
+    (160923)
+    
     if manual
     then params is a tuple
     params = (t1,t2,t3,dab,r1,r2,r3)
 
-    NE MARCHE PAS PARCE BESOIN DU RATE(TAUX) DES PARAMS D'HELMERT !!!!!!
-    (160923)
     """
+
+
+    
     if invert:
         inver = -1.
     else:
@@ -1362,7 +1411,6 @@ def mat_poids(Sinp,Ninp,fuvinp=1):
     Ktemp = []
 
     for i in range(len(Sinp)):
-        print(Sinp[i])
         Ktemp.append(np.eye(Ninp[i]) * Sinp[i]**2)
 
     K = scipy.linalg.block_diag(*Ktemp)
