@@ -33,14 +33,16 @@ import re
 ### disabled and imported directly in the needed fct
 ## import geodezyx.reffram.sofa18 as sofa
 
-
-
 #### geodeZYX modules
 from geodezyx import conv
 from geodezyx import files_rw
 from geodezyx import stats
 from geodezyx import utils
 
+#### Import the logger
+import logging
+log = logging.getLogger(__name__)
+
 ##########  END IMPORT  ##########
 
 def compar_orbit(Data_inp_1,Data_inp_2,step_data = 900,
@@ -109,8 +111,8 @@ def compar_orbit(Data_inp_1,Data_inp_2,step_data = 900,
     This Note is in fact usefull if you want to see bad positions on a plot
     => Then convert_ECEF_ECI = False and clean_null_values = False
 
-    Source
-    ------
+    References
+    ----------
     "Coordinate Systems", ASEN 3200 1/24/06 George H. Born
 
     """
@@ -195,11 +197,9 @@ def compar_orbit(Data_inp_1,Data_inp_2,step_data = 900,
 
         if np.any(D1_null_bool) or np.any(D2_null_bool):
             sat_nul = utils.join_improved(" " ,*list(set(D1orig[D1_null_bool]["sat"])))
-            print("WARN : Null values contained in SP3 files : ")
-            print("f1:" , np.sum(D1_null_bool) , utils.join_improved(" " ,
-                  *list(set(D1orig[D1_null_bool]["sat"]))))
-            print("f2:" , np.sum(D2_null_bool) , utils.join_improved(" " ,
-                  *list(set(D2orig[D2_null_bool]["sat"]))))
+            log.warning("Null values contained in SP3 files : ")
+            log.warning("f1: %s %s" , np.sum(D1_null_bool) , utils.join_improved(" " , *list(set(D1orig[D1_null_bool]["sat"]))))
+            log.warning("f2: %s %s" , np.sum(D2_null_bool) , utils.join_improved(" " , *list(set(D2orig[D2_null_bool]["sat"]))))
         else:
             sat_nul = []
 
@@ -240,11 +240,11 @@ def compar_orbit(Data_inp_1,Data_inp_2,step_data = 900,
                 D1sv_orig = D1window[D1window['sv'] == svv].reindex(epoc_set)
                 D2sv_orig = D2window[D2window['sv'] == svv].reindex(epoc_set)
             except Exception as exce:
-                print("ERR : Unable to re-index with an unique epoch")
-                print("      are you sure there is no multiple-defined epochs for the same sat ?")
-                print("      it happens e.g. when multiple ACs are in the same DataFrame ")
-                print("TIP : Filter the input Dataframe before calling this fct with")
-                print("      DF = DF[DF['AC'] == 'gbm']")
+                log.info("ERR : Unable to re-index with an unique epoch")
+                log.info("      are you sure there is no multiple-defined epochs for the same sat ?")
+                log.info("      it happens e.g. when multiple ACs are in the same DataFrame ")
+                log.info("TIP : Filter the input Dataframe before calling this fct with")
+                log.info("      DF = DF[DF['AC'] == 'gbm']")
                 
                 Dtmp1 = D1orig[D1orig['sv'] == svv]
                 Dtmp2 = D2orig[D2orig['sv'] == svv]
@@ -252,7 +252,7 @@ def compar_orbit(Data_inp_1,Data_inp_2,step_data = 900,
                 dupli1 = np.sum(Dtmp1.duplicated(["epoch","sat"]))
                 dupli2 = np.sum(Dtmp2.duplicated(["epoch","sat"]))
                 
-                print("FWIW : duplicated epoch/sat in DF1 & DF2 : ",dupli1,dupli2)
+                log.info("FWIW: duplicated epoch/sat in DF1 & DF2: %s %s",dupli1,dupli2)
 
                 raise exce
 
@@ -260,7 +260,7 @@ def compar_orbit(Data_inp_1,Data_inp_2,step_data = 900,
             # This step is useless, because .reindex() will fill the DataFrame
             # with NaN
             if len(D1sv_orig) != len(D2sv_orig):
-                print("INFO : different epochs nbr for SV",svv,len(D1sv_orig),len(D2sv_orig))
+                log.info("different epochs nbr for SV %s %s %s",svv,len(D1sv_orig),len(D2sv_orig))
                 epoc_sv_set = sorted(list(set(D1sv_orig.index).intersection(set(D2sv_orig.index))))
                 D1sv = D1sv_orig.loc[epoc_sv_set]
                 D2sv = D2sv_orig.loc[epoc_sv_set]
@@ -550,9 +550,9 @@ def compar_orbit_table(Diff_sat_all_df_in,RMS_style = 'natural',
     RMS_style : str
         'natural': use the natural definition of the RMS
         'GRGS': RMS calc based on the GRGS definition of the RMS (OV help)
-                is actually the standard deviation
+        is actually the standard deviation
         'kouba': RMS as defined in Kouba et al. 1994, p75
-                 using the degree of freedom (3*Nobs - 7)
+        using the degree of freedom (3*Nobs - 7)
 
     light_tab : bool
         produce a table with only RMS, with min/max/arithmetic instead
@@ -601,9 +601,6 @@ def compar_orbit_table(Diff_sat_all_df_in,RMS_style = 'natural',
             rms_A = stats.rms_mean_kouba(Diffwork[col_name0])
             rms_B = stats.rms_mean_kouba(Diffwork[col_name1])
             rms_C = stats.rms_mean_kouba(Diffwork[col_name2])
-
-            
-            
             
         RMS3D = np.sqrt(rms_A**2 + rms_B**2 + rms_C**2)
 
@@ -743,6 +740,19 @@ def compar_clock(DFclk_inp_1,DFclk_inp_2,col_name = "name",bias_Col_name = "bias
         DFclk_diff.drop("AC",axis=1,inplace=True)
     DFclk_diff.rename({bias_Col_name:bias_Col_name+"_diff"},inplace=True,axis=1)
     
+    
+    # Name definitions
+    if 'ac' in DFclk_inp_1.columns:
+        DFclk_diff['name1'] = DFclk_inp_1.ac.values[0]
+    if 'AC' in DFclk_inp_1.columns:
+        DFclk_diff['name1'] = DFclk_inp_1.AC.values[0]
+    
+    if 'ac' in DFclk_inp_1.columns:
+        DFclk_diff['name2'] = DFclk_inp_2.ac.values[0]
+    if 'AC' in DFclk_inp_1.columns:
+        DFclk_diff['name2'] = DFclk_inp_2.AC.values[0]
+
+    
     return DFclk_diff
     
 def compar_clock_table(DFclk_diff_in,col_name = "name",bias_Col_name = "bias_diff"):
@@ -775,6 +785,140 @@ def compar_clock_table(DFclk_diff_in,col_name = "name",bias_Col_name = "bias_dif
     
     return DFcompar_out
 
+def compar_clk_plot(Diff_sat_all_df_in,
+                    save_plot=False,
+                    save_plot_dir="",
+                    save_plot_name="auto",
+                    save_plot_name_suffix=None,
+                    save_plot_ext=(".pdf",".png",".svg"),
+                    yaxis_limit=None,
+                    yaxis_label_unit="psec",
+                    col_name = 'name',
+                    bias_Col_name = 'bias'):
+    """
+    General description
+
+    Parameters
+    ----------
+    Diff_sat_all_df_in: DataFrame
+        a DataFrame produced by compar_clk
+        
+    yaxis_limit: 3-tuple iterable or 2-element tuple
+        force the y axis limits. must look like 
+        (ymin,ymax) to set all th axis at the same limits 
+    
+    col_name: Normally the name of the column with the sat names
+    bias_Col_name: The column with the clk values
+    Default: 'bias'
+
+    Returns
+    -------
+    the Figure and the 3 Axes if no save is asked
+    export path (str) if save is asked
+    but plot a plot anyway
+    """
+    
+    
+    import matplotlib.dates as mdates
+    fig,axr = plt.subplots(1,1,sharex='all')
+    Diff_sat_all_df_in = Diff_sat_all_df_in.reset_index()
+    satdispo = natsort.natsorted(list(set(Diff_sat_all_df_in[col_name])))
+    # satdispo = natsort.natsorted(list(set(Diff_sat_all_df_in['sat'])))
+       
+    SymbStk = []
+       
+    cm = plt.get_cmap('viridis')
+    NUM_COLORS = len(satdispo)
+    Colors = [cm(1.*i/NUM_COLORS) for i in range(NUM_COLORS)]
+       
+    
+    
+    Date = conv.numpy_dt2dt(Diff_sat_all_df_in.epoch.values[0])
+    Diff_sat_all_df_in.name = ' '.join(('Clock comparison  b/w',
+                                  Diff_sat_all_df_in.name1.values[0] ,'(ref.) and',
+                                  Diff_sat_all_df_in.name2.values[0] ,',',Date.strftime("%Y-%m-%d")))
+    # Pandas donesn't manage well iterable as attribute
+    # So, it is separated
+    try:
+        col_name0 = Diff_sat_all_df_in.frame_col_name1
+        col_name1 = Diff_sat_all_df_in.frame_col_name2
+        col_name2 = Diff_sat_all_df_in.frame_col_name3
+    except:
+        col_name0 = Diff_sat_all_df_in.columns[0]
+        col_name1 = Diff_sat_all_df_in.columns[1]
+        col_name2 = Diff_sat_all_df_in.columns[2]
+       
+    for satuse,color in zip(satdispo,Colors):
+        Diffuse = Diff_sat_all_df_in[Diff_sat_all_df_in[col_name] == satuse]
+       
+        Time = Diffuse.epoch
+        R    = Diffuse[bias_Col_name+'_diff']*10**12
+       
+       
+        #fig.fmt_xdata = mdates.DateFormatter('%Y-%m-%d')
+       
+        Symb = axr.plot(Time,R,label=satuse,c=color)
+       
+       
+        SymbStk.append(Symb[0])
+       
+        fig.autofmt_xdate()
+       
+       
+    ylabuni = " (" + yaxis_label_unit + ")"
+    
+       
+    axr.set_ylabel('Bias Diff.' + ylabuni)
+       
+       
+       
+    y_formatter = matplotlib.ticker.ScalarFormatter(useOffset=False)
+    axr.yaxis.set_major_formatter(y_formatter)
+       
+    
+    if yaxis_limit and len(yaxis_limit) == 3: ### indep. axis limit
+        axr.set_ylim(yaxis_limit[0])
+       
+    elif yaxis_limit and len(yaxis_limit) == 2:
+        axr.set_ylim(yaxis_limit)
+       
+    else:
+        pass
+        
+        
+    import matplotlib.dates as mdates
+    fig.fmt_xdata = mdates.DateFormatter('%Y-%m-%d')
+       
+    lgd = fig.legend(tuple(SymbStk), satdispo , loc='lower center',ncol=8,
+                     columnspacing=1)
+       
+    fig.set_size_inches(8.27,11.69)
+    plt.suptitle(Diff_sat_all_df_in.name)
+    plt.tight_layout()
+    plt.subplots_adjust(top=0.95)
+    plt.subplots_adjust(bottom=0.15)
+       
+    if save_plot:
+        if save_plot_name == "auto":
+            save_plot_name = Diff_sat_all_df_in.name1.values[0]+"_"+Diff_sat_all_df_in.name2.values[0]+"_"+Date.strftime("%Y-%m-%d")
+            
+        if save_plot_name_suffix:
+            save_plot_name = save_plot_name + '_' + save_plot_name_suffix
+       
+        for ext in save_plot_ext:
+            save_plot_path = os.path.join(save_plot_dir,save_plot_name)
+            plt.savefig(save_plot_path + ext)
+            return_val = save_plot_path
+            
+    else:
+        return_val = fig,(axr)
+
+    return return_val
+
+
+
+
+
 
 def compar_sinex(snx1 , snx2 , stat_select = None, invert_select=False,
                  out_means_summary=True,out_meta=True,out_dataframe = True,
@@ -784,13 +928,13 @@ def compar_sinex(snx1 , snx2 , stat_select = None, invert_select=False,
         week1 = utils.split_improved(os.path.basename(snx1),"_",".")[:]
         week2 = utils.split_improved(os.path.basename(snx2),"_",".")[:]
         if week1 != week2:
-            print("WARN : Dates of 2 input files are differents !!! It might be very bad !!!",week1,week2)
+            log.warning("Dates of 2 input files are differents !!! It might be very bad !!! %s %s",week1,week2)
         else:
             wwwwd = week1
         D1 = files_rw.read_sinex(snx1,True)
         D2 = files_rw.read_sinex(snx2,True)
     else:
-        print("WARN : you are giving the SINEX input as a DataFrame, wwwwd has to be given manually using manu_wwwwd")
+        log.warning("WARN : you are giving the SINEX input as a DataFrame, wwwwd has to be given manually using manu_wwwwd")
         D1 = snx1
         D2 = snx2
 
@@ -815,7 +959,7 @@ def compar_sinex(snx1 , snx2 , stat_select = None, invert_select=False,
         elif utils.is_iterable(stat_select):
             STATCommon = [sta for sta in STATCommon_init if select_fct(sta in stat_select) ]
         else:
-            print("WARN : check type of stat_select")
+            log.warning("WARN : check type of stat_select")
 
     D1Common = D1[D1["STAT"].isin(STATCommon)].sort_values("STAT").reset_index(drop=True)
     D2Common = D2[D2["STAT"].isin(STATCommon)].sort_values("STAT").reset_index(drop=True)
@@ -869,7 +1013,7 @@ def compar_sinex(snx1 , snx2 , stat_select = None, invert_select=False,
 
 
     if not out_means_summary:
-        print("INFO : this is not used operationally and it can be improved")
+        log.info("INFO : this is not used operationally and it can be improved")
         return Ddiff
     else:
         output = []
@@ -885,7 +1029,6 @@ def compar_sinex(snx1 , snx2 , stat_select = None, invert_select=False,
             output.append(np.nanstd(Ddiff[xyz]))
 
         if out_meta:
-            print(wwwwd)
             nstat = len(STATCommon)
             week   = int(wwwwd[:4])
             day    = int(wwwwd[4:])
@@ -952,7 +1095,7 @@ def OrbDF_lagrange_interpolate(DForb_in,Titrp,n=10,
     
     for sat,ac in itertools.product(DForb_in.sat.unique(),DForb_in.AC.unique()):
         
-        print("INFO: lagrange_interpolate_sp3: process",ac,sat)
+        log.info("process",ac,sat)
         
         DForb_use = DForb_in[(DForb_in.sat == sat) & (DForb_in.AC == ac)].copy()
             
@@ -976,8 +1119,13 @@ def OrbDF_lagrange_interpolate(DForb_in,Titrp,n=10,
         DForb_stk.append(DForb_tmp)
         
         if plot:
-            plt.plot(Tdata,DForb_use.x,'o')
-            plt.plot(Titrp,Xitrp,'.')
+            # plt.plot(Tdata,DForb_use.x,'o')
+            # plt.plot(Titrp,Xitrp,'.')  
+            ## GUS mod 220322
+            fig,axr = plt.subplots(1,1,sharex='all')
+            Symb = axr.plot(Tdata,DForb_use.x,'o')
+            Symb = axr.plot(Titrp,Xitrp,'.')
+
         
     
     DForb_out = pd.concat(DForb_stk)
@@ -1108,10 +1256,8 @@ def OrbDF_common_epoch_finder(OrbDFa_in,OrbDFb_in,return_index=False,
     but can be used for snx files as STAT and epoch
     """
     
-    #print("666:",dt.datetime.now())
     OrbDFa = OrbDF_reg_2_multidx(OrbDFa_in,index_order = order)
     OrbDFb = OrbDF_reg_2_multidx(OrbDFb_in,index_order = order)
-    #print("777:",dt.datetime.now())
     
     I1 = OrbDFa.index
     I2 = OrbDFb.index
@@ -1134,10 +1280,8 @@ def OrbDF_common_epoch_finder(OrbDFa_in,OrbDFb_in,return_index=False,
 
     
     if len(OrbDFa_out) != len(OrbDFb_out):
-        print("WARN : Orb/ClkDF_common_epoch_finder : len(Orb/ClkDFa_out) != len(Orb/ClkDFb_out)")
-        print("TIPS : ClkDFa_in and/or ClkDFb_in might contain duplicates")
-
-#    print("888:",dt.datetime.now())
+        log.warning("len(Orb/ClkDFa_out) != len(Orb/ClkDFb_out)")
+        log.warning("TIPS : ClkDFa_in and/or ClkDFb_in might contain duplicates")
     
     if return_index:
         return OrbDFa_out , OrbDFb_out , Iinter
@@ -1411,13 +1555,35 @@ def svn_prn_equiv(sat_in,date_in,
     DFout = DFsat[Bool_date]
     
     if len(DFout) != 1:
-        print("WARN: several or no " + mode +  " entries !!!",sat_in,date_in)
+        log.warning("several or no %s entries !!! %s %s",mode,sat_in,date_in)
         
     if full_output:
         return DFout
     else:
         return DFout[svnorprn2].values[0]
     
+    
+def get_block_svn(sat_in,svn_prn_equiv_DF):
+    """
+    Get the equivalence SVN block type
+    
+    Parameters
+    ----------
+    sat_in : str
+        Satellite SVN.
+    svn_prn_equiv_DF : DataFrame
+        Equivalence table generated by svn_prn_equiv_DF.
+    Returns
+    -------
+    str with the block name
+    """
+    DFsat = svn_prn_equiv_DF[svn_prn_equiv_DF['SVN'] == sat_in]
+    # if DFsat.empty:
+    #     print('SVN NOT FOUND')
+    # else:        
+    block = DFsat.Block.values[0]
+
+    return block    
 
 
 def stats_slr(DFin,grpby_keys = ['sat'],
@@ -1501,8 +1667,8 @@ def eop_interpotate(DF_EOP,Epochs_intrp,eop_params = ["x","y"]):
         try:
             Out_eop[eoppar] = I(Epochs_intrp)
         except ValueError as err:
-            print("ERR: in EOP interpolation")
-            print("param.:",eoppar,"epoch:",Epochs_intrp)
+            log.error("in EOP interpolation")
+            log.error("param.: %s, epoch: %s",eoppar,Epochs_intrp)
             raise err
       
     if not singleton:
